@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Result;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains the result of a JSON Schema evaluation
 
-our $VERSION = '0.550';
+our $VERSION = '0.551';
 
 use 5.020;
 use Moo;
@@ -15,7 +15,7 @@ no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use MooX::TypeTiny;
-use Types::Standard qw(ArrayRef InstanceOf Enum);
+use Types::Standard qw(ArrayRef InstanceOf Enum Bool);
 use MooX::HandlesVia;
 use JSON::Schema::Modern::Annotation;
 use JSON::Schema::Modern::Error;
@@ -68,11 +68,19 @@ has output_format => (
   default => 'basic',
 );
 
+has formatted_annotations => (
+  is => 'ro',
+  isa => Bool,
+  default => 1,
+);
+
 sub BUILD ($self, $) {
   warn 'result is false but there are no errors' if not $self->valid and not $self->error_count;
 }
 
-sub format ($self, $style) {
+sub format ($self, $style, $formatted_annotations = undef) {
+  $formatted_annotations //= $self->formatted_annotations;
+
   if ($style eq 'flag') {
     return +{ valid => $self->valid };
   }
@@ -80,7 +88,7 @@ sub format ($self, $style) {
     return +{
       valid => $self->valid,
       $self->valid
-        ? ($self->annotation_count ? (annotations => [ map $_->TO_JSON, $self->annotations ]) : ())
+        ? ($formatted_annotations && $self->annotation_count ? (annotations => [ map $_->TO_JSON, $self->annotations ]) : ())
         : (errors => [ map $_->TO_JSON, $self->errors ]),
     };
   }
@@ -89,7 +97,7 @@ sub format ($self, $style) {
     return +{
       valid => $self->valid,
       $self->valid
-        ? ($self->annotation_count ? (annotations => [ map _map_uris($_->TO_JSON), $self->annotations ]) : ())
+        ? ($formatted_annotations && $self->annotation_count ? (annotations => [ map _map_uris($_->TO_JSON), $self->annotations ]) : ())
         : (errors => [ map _map_uris($_->TO_JSON), $self->errors ]),
     };
   }
@@ -125,7 +133,7 @@ sub format ($self, $style) {
     return +{
       valid => $self->valid,
       $self->valid
-        ? ($self->annotation_count ? (annotations => [ map $_->TO_JSON, $self->annotations ]) : ())
+        ? ($formatted_annotations && $self->annotation_count ? (annotations => [ map $_->TO_JSON, $self->annotations ]) : ())
         : (errors => [ map $_->TO_JSON, @errors ]),
     };
   }
@@ -151,6 +159,7 @@ sub combine ($self, $other, $swap) {
       $other->errors,
     ],
     output_format => $self->output_format,
+    formatted_annotations => $self->formatted_annotations || $other->formatted_annotations,
   );
 }
 
@@ -192,7 +201,7 @@ JSON::Schema::Modern::Result - Contains the result of a JSON Schema evaluation
 
 =head1 VERSION
 
-version 0.550
+version 0.551
 
 =head1 SYNOPSIS
 
@@ -278,6 +287,10 @@ C<allOf> failed evaluation).
 
 =back
 
+=head2 formatted_annotations
+
+A boolean flag indicating whether L</format> should include annotations in the output. Defaults to true.
+
 =head1 METHODS
 
 =for Pod::Coverage BUILD OUTPUT_FORMATS result stringify
